toasts property

List<Toast> get toasts

view all the toasts; usually you won't use this method, but it might be useful if you're attempting to see if a toast was already inserted:

example:

if (!toaster.of(context).toasts.any((toast) => toast.id == 'uniqueToast'))  {
  toaster.of(context).add(Toast(
    type: warningToast,
    id: 'uniqueToast',
    message: "my unique toast"
  ))
}

Implementation

List<Toast> get toasts;